@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2003-2013  Simon Ekstrand
- * Copyright (c) 2010-2020  Joachim Nilsson
+ * Copyright (c) 2010-2024  Joachim Wiberg
  * 
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -131,7 +131,7 @@ int validate_netmask(char *in_addr)
 		return 0;
 
 	while (i < (int)strlen(in_addr) && !j) {
-		if (!isxdigit(in_addr[i]) && in_addr[i] != 'x' && in_addr[i] != 'X')
+		if (!isxdigit((int)in_addr[i]) && in_addr[i] != 'x' && in_addr[i] != 'X')
 			j = 1;
 		if (in_addr[i] == 'x' || in_addr[i] == 'X') {
 			k++;
