@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2003-2013  Simon Ekstrand
- * Copyright (c) 2010-2020  Joachim Nilsson
+ * Copyright (c) 2010-2024  Joachim Wiberg
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -27,13 +27,16 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
+#endif
+#ifdef HAVE_GETOPT_H
+# include <getopt.h>
 #endif
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+# include <unistd.h>
 #endif
 #ifdef STDC_HEADERS
-#include <stdlib.h>
+# include <stdlib.h>
 #endif
 #include <stdio.h>
 #include <string.h>
@@ -42,12 +45,11 @@
 #include "output.h"
 
 char *ident = PACKAGE_NAME;
-extern char *optarg;
-extern int optind, opterr, optopt;
+int colorize = 1;
 
-int
-out_cmdline(struct if_info *ifarg_cur, int v4args, struct misc_args m_argv4,
-	    int v6args, struct misc_args m_argv6)
+
+int out_cmdline(struct if_info *ifarg_cur, int v4args, struct misc_args m_argv4,
+		int v6args, struct misc_args m_argv6)
 {
 	int ret = 0;
 
@@ -153,10 +155,10 @@ int cleanline(char *sbuf, char *dbuf)
 			y++;
 		}
 
-		while (sbuf[x] == ' ' && x < (int)strlen(sbuf))
+		while (x < (int)strlen(sbuf) && sbuf[x] == ' ')
 			x++;
 
-		while (sbuf[x] != ' ' && x < (int)strlen(sbuf)) {
+		while (x < (int)strlen(sbuf) && sbuf[x] != ' ') {
 			dbuf[y] = sbuf[x];
 			y++;
 			x++;
@@ -485,7 +487,7 @@ static int usage(int code)
 	       "  -S MASK     Split the IPv6 network into subnets of MASK size\n"
 	       "\n"
 	       "Copyright (C) 2003-2013  Simon Ekstrand\n"
-	       "Copyright (C) 2010-2020  Joachim Nilsson\n"
+	       "Copyright (C) 2010-2024  Joachim Wiberg\n"
 	       "\n"
 	       "This is free software, under the 3-clause BSD license: you are free to change\n"
 	       "and redistribute it.  There is NO WARRANTY, to the extent permitted by law.\n", ident);
@@ -615,9 +617,6 @@ int main(int argc, char *argv[])
 	if (!abox_start)
 		err(1, "Fatal error");
 
-	if (!isatty(STDIN_FILENO) || !isatty(STDOUT_FILENO))
-		colorize = 0;
-
 	if (split_errv4 || split_errv6 || range_err) {
  nothing:
 		warnx("No (valid) commands received, nothing to do.");
@@ -698,7 +697,7 @@ int main(int argc, char *argv[])
 			free(abox_cur);
 			abox_cur = NULL;
 
-			ifarg_cur = ifarg_start = parse_abox(abox_start);
+			ifarg_start = parse_abox(abox_start);
 			if (ifarg_start) {
 				ifarg_cur = ifarg_start;
 				while (ifarg_cur) {
